Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: chrome/browser/sync/glue/bookmark_model_associator.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/bookmark_model_associator.h
diff --git a/chrome/browser/sync/glue/bookmark_model_associator.h b/chrome/browser/sync/glue/bookmark_model_associator.h
index fe29ba50b44b08a366b82add6b803633cc276fad..e6e01311e946ed723698f1537e495e5b4c6bf862 100644
--- a/chrome/browser/sync/glue/bookmark_model_associator.h
+++ b/chrome/browser/sync/glue/bookmark_model_associator.h
@@ -21,7 +21,7 @@
class BookmarkModel;
class BookmarkNode;
-namespace csync {
+namespace syncer {
class BaseNode;
struct UserShare;
}
@@ -41,7 +41,7 @@ class BookmarkModelAssociator
// Should be set to true only by mobile clients.
BookmarkModelAssociator(
BookmarkModel* bookmark_model,
- csync::UserShare* user_share,
+ syncer::UserShare* user_share,
DataTypeErrorHandler* unrecoverable_error_handler,
bool expect_mobile_bookmarks_folder);
virtual ~BookmarkModelAssociator();
@@ -58,16 +58,16 @@ class BookmarkModelAssociator
// node. After successful completion, the models should be identical and
// corresponding. Returns true on success. On failure of this step, we
// should abort the sync operation and report an error to the user.
- virtual csync::SyncError AssociateModels() OVERRIDE;
+ virtual syncer::SyncError AssociateModels() OVERRIDE;
- virtual csync::SyncError DisassociateModels() OVERRIDE;
+ virtual syncer::SyncError DisassociateModels() OVERRIDE;
// The has_nodes out param is true if the sync model has nodes other
// than the permanent tagged nodes.
virtual bool SyncModelHasUserCreatedNodes(bool* has_nodes) OVERRIDE;
// Returns sync id for the given bookmark node id.
// Returns csync::kInvalidId if the sync node is not found for the given
// bookmark node id.
virtual int64 GetSyncIdFromChromeId(const int64& node_id) OVERRIDE;
@@ -80,7 +80,7 @@ class BookmarkModelAssociator
// if the initialization of sync node fails.
virtual bool InitSyncNodeFromChromeId(
const int64& node_id,
- csync::BaseNode* sync_node) OVERRIDE;
+ syncer::BaseNode* sync_node) OVERRIDE;
// Associates the given bookmark node with the given sync id.
virtual void Associate(const BookmarkNode* node, int64 sync_id) OVERRIDE;
@@ -118,23 +118,23 @@ class BookmarkModelAssociator
// Matches up the bookmark model and the sync model to build model
// associations.
- csync::SyncError BuildAssociations();
+ syncer::SyncError BuildAssociations();
// Associate a top-level node of the bookmark model with a permanent node in
// the sync domain. Such permanent nodes are identified by a tag that is
// well known to the server and the client, and is unique within a particular
// user's share. For example, "other_bookmarks" is the tag for the Other
// Bookmarks folder. The sync nodes are server-created.
- csync::SyncError AssociateTaggedPermanentNode(
+ syncer::SyncError AssociateTaggedPermanentNode(
const BookmarkNode* permanent_node,
const std::string& tag) WARN_UNUSED_RESULT;
// Compare the properties of a pair of nodes from either domain.
bool NodesMatch(const BookmarkNode* bookmark,
- const csync::BaseNode* sync_node) const;
+ const syncer::BaseNode* sync_node) const;
BookmarkModel* bookmark_model_;
- csync::UserShare* user_share_;
+ syncer::UserShare* user_share_;
DataTypeErrorHandler* unrecoverable_error_handler_;
const bool expect_mobile_bookmarks_folder_;
BookmarkIdToSyncIdMap id_map_;
@@ -58,16 +58,16 @@ class BookmarkModelAssociator
virtual bool SyncModelHasUserCreatedNodes(bool* has_nodes) OVERRIDE;
// Returns sync id for the given bookmark node id.
- // Returns csync::kInvalidId if the sync node is not found for the given
+ // Returns syncer::kInvalidId if the sync node is not found for the given
// bookmark node id.
virtual int64 GetSyncIdFromChromeId(const int64& node_id) OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698